***Replication Code for Correlates of Warning***
**Use file "Correlates_of_Warning_replication.dta"**

**Note: Multilevel models and marginal effects may take considerable time to run**

***Table 1: descriptive statistics***
summarize Warning
summarize Territory
summarize Domestic_Territory 
summarize Foreign_Territory 
summarize State_Sponsored 
summarize Resources 
summarize Polity2 
summarize Separatist 
summarize Religious 
summarize Ethnic 
summarize Leftist 
summarize Reactionary 
summarize Suicide
summarize Utilities
summarize Private_Citizens 
summarize Government 
summarize Business 
summarize Civil_Society 
summarize Infrastructure 
summarize Tourists

*Frequency of warnings among groups that warn sometimes*
summarize Warning if group_warns_sometimes==1



***Table 2: Multilevel Logit Results***

*Model 1**

melogit Warning Religious Ethnic Leftist Reactionary Separatist || gnumber_new: , difficult nolog

*Model 2*

melogit Warning Territory Polity2 State_Sponsored Resources || gnumber_new: Polity2, difficult nolog

*Model 3*

melogit Warning Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist|| gnumber_new: Polity2, difficult nolog

*Model 4*

melogit Warning Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide || gnumber_new: Polity2 Suicide, difficult nolog

*Model 5*

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

*Model 6*****

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious Religious_Suicide Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

*Model 7

melogit Warning_targtypes Domestic_Territory Foreign_Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog


*Test equality of coefficients for Domestic_Territory and Foreign_Territory*
test Domestic_Territory=Foreign_Territory

*Note: for likelihood ratio tests of model specification, see lines 270-334*


***Table 3: Pearson Correlation Matrix***

corr Religious Territory Polity2




***Figure 1 (Average Marginal Effects)***
*Note: must install plotplainblind scheme*
*Installation code: ssc install blindschemes*

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

margins, dydx(Territory State_Sponsored Resources Polity2 Separatist Religious Ethnic Leftist Reactionary Suicide)

marginsplot, horizontal xline(0) title("") yscale(reverse) ytitle("") recast(scatter) scheme(plotplainblind)


***For discussion of marginal effects***

**Calculating predicted probabilities at specific values of Territory and Polity2**
margins , at (Territory=(0) Polity2=(0) State_Sponsored=(0) Resources=(0) Religious=(0) Ethnic=(0) Leftist=(0) Reactionary=(0) Separatist=(0) Suicide=(0) Private_Citizens=(0) Government=(0) Business=(0) Civil_Society=(0) Infrastructure=(0) Tourists=(0))
margins , atmeans
margins , at (Territory=(0 1))
margins , at (Polity2=(-10 10))
margins , at (Polity2=(-10) Territory=(1))
margins , at (Polity2=(10) Territory=(0))
margins , at (Polity2=(5.14) Territory=(1))
margins , at (Polity2=(7.18) Territory=(1))




**Generating group statistics for comparison to predicted probabilities**
*Note: group numbers (gnumber_new) are used to generate statistics because the GTD denotes groups with multiple names & spellings*

*Kurdistan Workers' Party (PKK)*
summarize Territory if gnumber_new==20
summarize Polity2 if gnumber_new==20
summarize Warning if gnumber_new==20
*Al-Shabaab*
summarize Territory if gnumber_new==6
summarize Polity2 if gnumber_new==6
summarize Warning if gnumber_new==6
*Boko Haram*
summarize Territory if gnumber_new==9
summarize Polity2 if gnumber_new==9
summarize Warning if gnumber_new==9
summarize Warning if gnumber_new==9 & Territory==1
summarize Warning if gnumber_new==9 & Territory==0
*Free Syrian Army*
summarize Territory if gnumber_new==52
summarize Polity2 if gnumber_new==52
summarize Warning if gnumber_new==52
*Dev Sol*
summarize Territory if gnumber_new==32
summarize Polity2 if gnumber_new==32
summarize Warning if gnumber_new==32
*November 17 Revolutionary Organization*
summarize Territory if gnumber_new==66
summarize Polity2 if gnumber_new==66
summarize Warning if gnumber_new==66
*FALN*
summarize Territory if gnumber_new==16
summarize Polity2 if gnumber_new==16
summarize Warning if gnumber_new==16
*ETA*
summarize Territory if gnumber_new==8
summarize Polity2 if gnumber_new==8
summarize Warning if gnumber_new==8
*IRA*
summarize Territory if gnumber_new==19
summarize Polity2 if gnumber_new==19
summarize Warning if gnumber_new==19
*ETA (continued)*
tab targtype1_txt if gnumber_new==8
summarize Warning if Tourists==1
summarize Warning if gnumber_new==8
summarize Warning if gnumber_new==8
*FARC*
summarize Territory if gnumber_new==32
summarize Polity2 if gnumber_new==32
summarize Warning if gnumber_new==32
*Islamic State/ISI/AQI*
summarize Territory if gnumber_new==41
summarize Polity2 if gnumber_new==41
summarize Warning if gnumber_new==41





***Appendix Descriptive Statistics & Regression Tables***
*Note: for Tables 4-6 (Codings of Militant Groups) see end of .do file, lines 339-2433*

***Table 7: descriptive statistics***
summarize Vacant_Site
summarize Free_Press
summarize PTS
summarize Democ
summarize Autoc
summarize Freedom_House_PR
summarize Freedom_House_CL
summarize Polity2_Local

***Table 8: Multilevel Logit Results: Vacant Sites, Press Freedom, Polity2 “local”, Polity2_squared***

*Model 1*

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists Vacant_Site || gnumber_new: Polity2 Suicide, difficult nolog

*Model 2*

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists Free_Press || gnumber_new: Polity2 Suicide, difficult nolog

*Model 3*

melogit Warning_targtypes Territory Polity2_Local State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2_Local Suicide, difficult nolog

*Model 4*

melogit Warning_targtypes Territory Polity2 Polity2_Squared State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog


***Table 9: Multilevel Logit Results with Different Democracy/Autocracy Measures***

*Model 1*

melogit Warning_targtypes Territory PTS State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: PTS Suicide, difficult nolog

*Model 2*

melogit Warning_targtypes Territory Democ State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Democ Suicide, difficult nolog

*Model 3*

melogit Warning_targtypes Territory Autoc State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Autoc Suicide, difficult nolog

*Model 4*

melogit Warning_targtypes Territory Freedom_House_PR State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Freedom_House_PR Suicide, difficult nolog

*Model 5*

melogit Warning_targtypes Territory Freedom_House_CL State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Freedom_House_CL Suicide, difficult nolog


***Table 10: Multilevel Logit Results with Higher Inclusion Thresholds***

*Model 1*

melogit  Warning_targtypes_50up Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

*Model 2*

melogit  Warning_targtypes_75up Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

*Model 3*

melogit  Warning_targtypes_100up Territory Polity2 State_Sponsored Resources Religious Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog


***Table 11: Logit Results with Group Fixed Effects***

*Model 1*

logit Warning Territory State_Sponsored Resources Polity2 gdum1 gdum2 gdum4 gdum5 gdum6 gdum7 gdum8 gdum9 gdum10 gdum11 gdum12 gdum13 gdum14 gdum15 gdum16 gdum17 gdum18 gdum19 gdum20 gdum21 gdum22 gdum23 gdum24 gdum25 gdum26 gdum27 gdum28 gdum29 gdum30 gdum31 gdum32 gdum33 gdum34 gdum35 gdum36 gdum37 gdum38 gdum39 gdum40 gdum41 gdum42 gdum43 gdum44 gdum45 gdum46 gdum47 gdum48 gdum49 gdum50 gdum51 gdum52 gdum54 gdum55 gdum57 gdum58 gdum59 gdum60 gdum61 gdum62 gdum63 gdum64 gdum65 gdum66 gdum67 gdum69 gdum70 gdum71 gdum72 gdum73 gdum74 gdum75 gdum76 gdum77 gdum78 gdum79 gdum80 gdum81 gdum82 gdum83 gdum84 gdum85 gdum86 gdum87 gdum88 gdum89 gdum90 gdum91 gdum92 gdum93 gdum94 gdum95 gdum96 gdum97 gdum98 gdum99 gdum100 gdum101 gdum102 gdum103 gdum104 gdum105 gdum106 gdum107 gdum108 gdum109 gdum111 gdum112 gdum113 gdum114 gdum115 gdum116 gdum117 gdum118 gdum119 gdum120 gdum122 gdum123 gdum124 gdum125 gdum126 gdum127 gdum128 gdum129 gdum130 gdum131 gdum132 gdum133 gdum134 gdum135 gdum136 gdum137 , nolog


*Model 2*

logit Warning Territory State_Sponsored Resources Polity2 Suicide gdum1 gdum2 gdum4 gdum5 gdum6 gdum7 gdum8 gdum9 gdum10 gdum11 gdum12 gdum13 gdum14 gdum15 gdum16 gdum17 gdum18 gdum19 gdum20 gdum21 gdum22 gdum23 gdum24 gdum25 gdum26 gdum27 gdum28 gdum29 gdum30 gdum31 gdum32 gdum33 gdum34 gdum35 gdum36 gdum37 gdum38 gdum39 gdum40 gdum41 gdum42 gdum43 gdum44 gdum45 gdum46 gdum47 gdum48 gdum49 gdum50 gdum51 gdum52 gdum54 gdum55 gdum57 gdum58 gdum59 gdum60 gdum61 gdum62 gdum63 gdum64 gdum65 gdum66 gdum67 gdum69 gdum70 gdum71 gdum72 gdum73 gdum74 gdum75 gdum76 gdum77 gdum78 gdum79 gdum80 gdum81 gdum82 gdum83 gdum84 gdum85 gdum86 gdum87 gdum88 gdum89 gdum90 gdum91 gdum92 gdum93 gdum94 gdum95 gdum96 gdum97 gdum98 gdum99 gdum100 gdum101 gdum102 gdum103 gdum104 gdum105 gdum106 gdum107 gdum108 gdum109 gdum111 gdum112 gdum113 gdum114 gdum115 gdum116 gdum117 gdum118 gdum119 gdum120 gdum122 gdum123 gdum124 gdum125 gdum126 gdum127 gdum128 gdum129 gdum130 gdum131 gdum132 gdum133 gdum134 gdum135 gdum136 gdum137 , nolog


*Model 3*

logit Warning_targtypes Territory State_Sponsored Resources Polity2 Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists gdum1 gdum2 gdum4 gdum5 gdum6 gdum7 gdum8 gdum9 gdum10 gdum11 gdum12 gdum13 gdum14 gdum15 gdum16 gdum17 gdum18 gdum19 gdum20 gdum21 gdum22 gdum23 gdum24 gdum25 gdum26 gdum27 gdum28 gdum29 gdum30 gdum31 gdum32 gdum33 gdum34 gdum35 gdum36 gdum37 gdum38 gdum39 gdum40 gdum41 gdum42 gdum43 gdum44 gdum45 gdum46 gdum47 gdum48 gdum49 gdum50 gdum51 gdum52 gdum54 gdum55 gdum57 gdum58 gdum59 gdum60 gdum61 gdum62 gdum63 gdum64 gdum65 gdum66 gdum67 gdum69 gdum70 gdum71 gdum72 gdum73 gdum74 gdum75 gdum76 gdum77 gdum78 gdum79 gdum80 gdum81 gdum82 gdum83 gdum84 gdum85 gdum86 gdum87 gdum88 gdum89 gdum90 gdum91 gdum92 gdum93 gdum94 gdum95 gdum96 gdum97 gdum98 gdum99 gdum100 gdum101 gdum102 gdum103 gdum104 gdum105 gdum106 gdum107 gdum108 gdum109 gdum111 gdum112 gdum113 gdum114 gdum115 gdum116 gdum117 gdum118 gdum119 gdum120 gdum122 gdum123 gdum124 gdum125 gdum126 gdum127 gdum128 gdum129 gdum130 gdum131 gdum132 gdum133 gdum134 gdum135 gdum136 gdum137 , nolog


*Model 4*

logit Warning_targtypes Domestic_Territory Foreign_Territory State_Sponsored Resources Polity2 Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists gdum1 gdum2 gdum4 gdum5 gdum6 gdum7 gdum8 gdum9 gdum10 gdum11 gdum12 gdum13 gdum14 gdum15 gdum16 gdum17 gdum18 gdum19 gdum20 gdum21 gdum22 gdum23 gdum24 gdum25 gdum26 gdum27 gdum28 gdum29 gdum30 gdum31 gdum32 gdum33 gdum34 gdum35 gdum36 gdum37 gdum38 gdum39 gdum40 gdum41 gdum42 gdum43 gdum44 gdum45 gdum46 gdum47 gdum48 gdum49 gdum50 gdum51 gdum52 gdum54 gdum55 gdum57 gdum58 gdum59 gdum60 gdum61 gdum62 gdum63 gdum64 gdum65 gdum66 gdum67 gdum69 gdum70 gdum71 gdum72 gdum73 gdum74 gdum75 gdum76 gdum77 gdum78 gdum79 gdum80 gdum81 gdum82 gdum83 gdum84 gdum85 gdum86 gdum87 gdum88 gdum89 gdum90 gdum91 gdum92 gdum93 gdum94 gdum95 gdum96 gdum97 gdum98 gdum99 gdum100 gdum101 gdum102 gdum103 gdum104 gdum105 gdum106 gdum107 gdum108 gdum109 gdum111 gdum112 gdum113 gdum114 gdum115 gdum116 gdum117 gdum118 gdum119 gdum120 gdum122 gdum123 gdum124 gdum125 gdum126 gdum127 gdum128 gdum129 gdum130 gdum131 gdum132 gdum133 gdum134 gdum135 gdum136 gdum137 , nolog




***Table 12: Multilevel Logit Results with Interactions***

*Model 1*

melogit Warning_targtypes Territory##Religious Polity2 State_Sponsored Resources Ethnic Leftist Reactionary Separatist Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog

*Model 2*

melogit Warning_targtypes Territory Polity2 State_Sponsored Resources Religious##Separatist Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity2 Suicide, difficult nolog





***Likelihood Ratio Tests***

*Testing random slope specification for each variable in Models 1-4 that shows within-group variation*

*Random Slopes for Polity_2 and Suicide*

melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: , difficult nolog

estimates store Random_intercept_only


melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity_2, difficult nolog

estimates store Random_slope_p2


melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Suicide, difficult nolog

estimates store Random_slope_sui


melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Polity_2 Suicide, difficult nolog

estimates store Random_slope_p2sui



lrtest Random_slope_p2 Random_intercept_only

lrtest Random_slope_sui Random_intercept_only

lrtest Random_slope_p2sui Random_intercept_only

lrtest Random_slope_p2sui Random_slope_p2

lrtest Random_slope_p2sui Random_slope_sui



*Random Slope for Territory*

melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Territory , difficult nolog

estimates store Random_slope_terr

lrtest Random_slope_terr Random_intercept_only



*Random Slope for State_Sponsored*

melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: State_Sponsored , difficult nolog

estimates store Random_slope_ss

lrtest Random_slope_ss Random_intercept_only


*Random Slope for Resources*

melogit Warning_targtypes Territory State_Sponsored Resources Polity_2 Separatist Religious Ethnic Leftist Reactionary Suicide Private_Citizens Government Business Civil_Society Infrastructure Tourists || gnumber_new: Resources , difficult nolog

estimates store Random_slope_res

lrtest Random_slope_res Random_intercept_only




***Codings of Militant Groups (to populate Tables 4-6)***

*Abu Sayyaf Group (ASG)*
summarize Warning if gnumber_new==1
tab target_state if gnumber_new==1
summarize Polity2 if gnumber_new==1
summarize PTS if gnumber_new==1
summarize Territory if gnumber_new==1
summarize State_Sponsored if gnumber_new==1
summarize Resources if gnumber_new==1
summarize Separatist if gnumber_new==1
summarize Suicide if gnumber_new==1
summarize Religious if gnumber_new==1
summarize Ethnic if gnumber_new==1
summarize Leftist if gnumber_new==1
summarize Reactionary if gnumber_new==1


*Action Directe*
summarize Warning if gnumber_new==80
tab target_state if gnumber_new==80
summarize Polity2 if gnumber_new==80
summarize PTS if gnumber_new==80
summarize Territory if gnumber_new==80
summarize State_Sponsored if gnumber_new==80
summarize Resources if gnumber_new==80
summarize Separatist if gnumber_new==80
summarize Suicide if gnumber_new==80
summarize Religious if gnumber_new==80
summarize Ethnic if gnumber_new==80
summarize Leftist if gnumber_new==80
summarize Reactionary if gnumber_new==80


*African National Congress (South Africa)*
summarize Warning if gnumber_new==2
tab target_state if gnumber_new==2
summarize Polity2 if gnumber_new==2
summarize PTS if gnumber_new==2
summarize Territory if gnumber_new==2
summarize State_Sponsored if gnumber_new==2
summarize Resources if gnumber_new==2
summarize Separatist if gnumber_new==2
summarize Suicide if gnumber_new==2
summarize Religious if gnumber_new==2
summarize Ethnic if gnumber_new==2
summarize Leftist if gnumber_new==2
summarize Reactionary if gnumber_new==2

 
*Ajnad Misr* 
summarize Warning if gnumber_new==81
tab target_state if gnumber_new==81
summarize Polity2 if gnumber_new==81
summarize PTS if gnumber_new==81
summarize Territory if gnumber_new==81
summarize State_Sponsored if gnumber_new==81
summarize Resources if gnumber_new==81
summarize Separatist if gnumber_new==81
summarize Suicide if gnumber_new==81
summarize Religious if gnumber_new==81
summarize Ethnic if gnumber_new==81
summarize Leftist if gnumber_new==81
summarize Reactionary if gnumber_new==81


*Al-Aqsa Martyrs Brigade*
summarize Warning if gnumber_new==48
tab target_state if gnumber_new==48
summarize Polity2 if gnumber_new==48
summarize PTS if gnumber_new==48 
summarize Territory if gnumber_new==48 
summarize State_Sponsored if gnumber_new==48 
summarize Resources if gnumber_new==48 
summarize Separatist if gnumber_new==48 
summarize Suicide if gnumber_new==48 
summarize Religious if gnumber_new==48
summarize Ethnic if gnumber_new==48
summarize Leftist if gnumber_new==48
summarize Reactionary if gnumber_new==48


*Al-Naqshabandiya Army* 
summarize Warning if gnumber_new==82
tab target_state if gnumber_new==82
summarize Polity2 if gnumber_new==82
summarize PTS if gnumber_new==82  
summarize Territory if gnumber_new==82 
summarize State_Sponsored if gnumber_new==82 
summarize Resources if gnumber_new==82
summarize Separatist if gnumber_new==82 
summarize Suicide if gnumber_new==82
summarize Religious if gnumber_new==82
summarize Ethnic if gnumber_new==82
summarize Leftist if gnumber_new==82
summarize Reactionary if gnumber_new==82

 
*Al-Nusrah Front*
summarize Warning if gnumber_new==43
tab target_state if gnumber_new==43
summarize Polity2 if gnumber_new==43
summarize PTS if gnumber_new==43  
summarize Territory if gnumber_new==43 
summarize State_Sponsored if gnumber_new==43 
summarize Resources if gnumber_new==43
summarize Separatist if gnumber_new==43 
summarize Suicide if gnumber_new==43
summarize Religious if gnumber_new==43
summarize Ethnic if gnumber_new==43
summarize Leftist if gnumber_new==43
summarize Reactionary if gnumber_new==43


*Al-Qa`ida*
summarize Warning if gnumber_new==83
tab target_state if gnumber_new==83
summarize Polity2 if gnumber_new==83
summarize PTS if gnumber_new==83  
summarize Territory if gnumber_new==83
summarize State_Sponsored if gnumber_new==83 
summarize Resources if gnumber_new==83
summarize Separatist if gnumber_new==83 
summarize Suicide if gnumber_new==83
summarize Religious if gnumber_new==83
summarize Ethnic if gnumber_new==83
summarize Leftist if gnumber_new==83
summarize Reactionary if gnumber_new==83


*Al-Qa`ida in the Arabian Peninsula (AQAP)*
summarize Warning if gnumber_new==4
tab target_state if gnumber_new==4
summarize Polity2 if gnumber_new==4
summarize PTS if gnumber_new==4
summarize Territory if gnumber_new==4
summarize State_Sponsored if gnumber_new==4 
summarize Resources if gnumber_new==4
summarize Separatist if gnumber_new==4 
summarize Suicide if gnumber_new==4
summarize Religious if gnumber_new==4
summarize Ethnic if gnumber_new==4
summarize Leftist if gnumber_new==4
summarize Reactionary if gnumber_new==4


*Al-Qa`ida in the Lands of the Islamic Maghreb (AQLIM)*
summarize Warning if gnumber_new==5
tab target_state if gnumber_new==5
summarize Polity2 if gnumber_new==5
summarize PTS if gnumber_new==5
summarize Territory if gnumber_new==5
summarize State_Sponsored if gnumber_new==5
summarize Resources if gnumber_new==5
summarize Separatist if gnumber_new==5
summarize Suicide if gnumber_new==5
summarize Religious if gnumber_new==5
summarize Ethnic if gnumber_new==5
summarize Leftist if gnumber_new==5
summarize Reactionary if gnumber_new==5


*Al-Shabaab*
summarize Warning if gnumber_new==6
tab target_state if gnumber_new==6
summarize Polity2 if gnumber_new==6
summarize PTS if gnumber_new==6
summarize Territory if gnumber_new==6
summarize State_Sponsored if gnumber_new==6
summarize Resources if gnumber_new==6
summarize Separatist if gnumber_new==6
summarize Suicide if gnumber_new==6
summarize Religious if gnumber_new==6
summarize Ethnic if gnumber_new==6
summarize Leftist if gnumber_new==6
summarize Reactionary if gnumber_new==6


*Ansar Allah (Houthis)*
summarize Warning if gnumber_new==44
tab target_state if gnumber_new==44
summarize Polity2 if gnumber_new==44
summarize PTS if gnumber_new==44
summarize Territory if gnumber_new==44
summarize State_Sponsored if gnumber_new==44
summarize Resources if gnumber_new==44
summarize Separatist if gnumber_new==44
summarize Suicide if gnumber_new==44
summarize Religious if gnumber_new==44
summarize Ethnic if gnumber_new==44
summarize Leftist if gnumber_new==44
summarize Reactionary if gnumber_new==44


*Ansar Bayt al-Maqdis*
summarize Warning if gnumber_new==85
tab target_state if gnumber_new==85
summarize Polity2 if gnumber_new==85
summarize PTS if gnumber_new==85
summarize Territory if gnumber_new==85
summarize State_Sponsored if gnumber_new==85
summarize Resources if gnumber_new==85
summarize Separatist if gnumber_new==85
summarize Suicide if gnumber_new==85
summarize Religious if gnumber_new==85
summarize Ethnic if gnumber_new==85
summarize Leftist if gnumber_new==85
summarize Reactionary if gnumber_new==85


*Ansar al-Sharia*
summarize Warning if gnumber_new==84
tab target_state if gnumber_new==84
summarize Polity2 if gnumber_new==84
summarize PTS if gnumber_new==84
summarize Territory if gnumber_new==84
summarize State_Sponsored if gnumber_new==84
summarize Resources if gnumber_new==84
summarize Separatist if gnumber_new==84
summarize Suicide if gnumber_new==84
summarize Religious if gnumber_new==84
summarize Ethnic if gnumber_new==84
summarize Leftist if gnumber_new==84
summarize Reactionary if gnumber_new==84


*April 6th Liberation Movement*
summarize Warning if gnumber_new==86
tab target_state if gnumber_new==86
summarize Polity2 if gnumber_new==86
summarize PTS if gnumber_new==86
summarize Territory if gnumber_new==86
summarize State_Sponsored if gnumber_new==86
summarize Resources if gnumber_new==86
summarize Separatist if gnumber_new==86
summarize Suicide if gnumber_new==86
summarize Religious if gnumber_new==86
summarize Ethnic if gnumber_new==86
summarize Leftist if gnumber_new==86
summarize Reactionary if gnumber_new==86


*Armed Forces of National Liberation (FALN)*
summarize Warning if gnumber_new==16
tab target_state if gnumber_new==16
summarize Polity2 if gnumber_new==16
summarize PTS if gnumber_new==16
summarize Territory if gnumber_new==16
summarize State_Sponsored if gnumber_new==16
summarize Resources if gnumber_new==16
summarize Separatist if gnumber_new==16
summarize Suicide if gnumber_new==16
summarize Religious if gnumber_new==16
summarize Ethnic if gnumber_new==16
summarize Leftist if gnumber_new==16
summarize Reactionary if gnumber_new==16


*Armed Islamic Group*
summarize Warning if gnumber_new==49
tab target_state if gnumber_new==49
summarize Polity2 if gnumber_new==49
summarize PTS if gnumber_new==49
summarize Territory if gnumber_new==49
summarize State_Sponsored if gnumber_new==49
summarize Resources if gnumber_new==49
summarize Separatist if gnumber_new==49
summarize Suicide if gnumber_new==49
summarize Religious if gnumber_new==49
summarize Ethnic if gnumber_new==49
summarize Leftist if gnumber_new==49
summarize Reactionary if gnumber_new==49


*Armenian Secret Army for the Liberation of Armenia* 
summarize Warning if gnumber_new==7
tab target_state if gnumber_new==7
summarize Polity2 if gnumber_new==7
summarize PTS if gnumber_new==7
summarize Territory if gnumber_new==7
summarize State_Sponsored if gnumber_new==7
summarize Resources if gnumber_new==7
summarize Separatist if gnumber_new==7
summarize Suicide if gnumber_new==7
summarize Religious if gnumber_new==7
summarize Ethnic if gnumber_new==7
summarize Leftist if gnumber_new==7
summarize Reactionary if gnumber_new==7


*Baloch Liberation Army (BLA)*
summarize Warning if gnumber_new==50
tab target_state if gnumber_new==50
summarize Polity2 if gnumber_new==50
summarize PTS if gnumber_new==50
summarize Territory if gnumber_new==50
summarize State_Sponsored if gnumber_new==50
summarize Resources if gnumber_new==50
summarize Separatist if gnumber_new==50
summarize Suicide if gnumber_new==50
summarize Religious if gnumber_new==50
summarize Ethnic if gnumber_new==50
summarize Leftist if gnumber_new==50
summarize Reactionary if gnumber_new==50


*Baloch Liberation Front (BLF)*
summarize Warning if gnumber_new==87
tab target_state if gnumber_new==87
summarize Polity2 if gnumber_new==87
summarize PTS if gnumber_new==87
summarize Territory if gnumber_new==87
summarize State_Sponsored if gnumber_new==87
summarize Resources if gnumber_new==87
summarize Separatist if gnumber_new==87
summarize Suicide if gnumber_new==87
summarize Religious if gnumber_new==87
summarize Ethnic if gnumber_new==87
summarize Leftist if gnumber_new==87
summarize Reactionary if gnumber_new==87


*Baloch Republican Army (BRA)*
summarize Warning if gnumber_new==38
tab target_state if gnumber_new==38
summarize Polity2 if gnumber_new==38
summarize PTS if gnumber_new==38
summarize Territory if gnumber_new==38
summarize State_Sponsored if gnumber_new==38
summarize Resources if gnumber_new==38
summarize Separatist if gnumber_new==38
summarize Suicide if gnumber_new==38
summarize Religious if gnumber_new==38
summarize Ethnic if gnumber_new==38
summarize Leftist if gnumber_new==38
summarize Reactionary if gnumber_new==38


*Bangladesh Nationalist Party (BNP)*
summarize Warning if gnumber_new==88
tab target_state if gnumber_new==88
summarize Polity2 if gnumber_new==88
summarize PTS if gnumber_new==88
summarize Territory if gnumber_new==88
summarize State_Sponsored if gnumber_new==88
summarize Resources if gnumber_new==88
summarize Separatist if gnumber_new==88
summarize Suicide if gnumber_new==88
summarize Religious if gnumber_new==88
summarize Ethnic if gnumber_new==88
summarize Leftist if gnumber_new==88
summarize Reactionary if gnumber_new==88


*Bangsamoro Islamic Freedom Movement (BIFM)*
summarize Warning if gnumber_new==39
tab target_state if gnumber_new==39
summarize Polity2 if gnumber_new==39
summarize PTS if gnumber_new==39
summarize Territory if gnumber_new==39
summarize State_Sponsored if gnumber_new==39
summarize Resources if gnumber_new==39
summarize Separatist if gnumber_new==39
summarize Suicide if gnumber_new==39
summarize Religious if gnumber_new==39
summarize Ethnic if gnumber_new==39
summarize Leftist if gnumber_new==39
summarize Reactionary if gnumber_new==39


*Barqa Province of the Islamic State*
summarize Warning if gnumber_new==51
tab target_state if gnumber_new==51
summarize Polity2 if gnumber_new==51
summarize PTS if gnumber_new==51
summarize Territory if gnumber_new==51
summarize State_Sponsored if gnumber_new==51
summarize Resources if gnumber_new==51
summarize Separatist if gnumber_new==51
summarize Suicide if gnumber_new==51
summarize Religious if gnumber_new==51
summarize Ethnic if gnumber_new==51
summarize Leftist if gnumber_new==51
summarize Reactionary if gnumber_new==51


*Black September*
summarize Warning if gnumber_new==89
tab target_state if gnumber_new==89
summarize Polity2 if gnumber_new==89
summarize PTS if gnumber_new==89
summarize Territory if gnumber_new==89
summarize State_Sponsored if gnumber_new==89
summarize Resources if gnumber_new==89
summarize Separatist if gnumber_new==89
summarize Suicide if gnumber_new==89
summarize Religious if gnumber_new==89
summarize Ethnic if gnumber_new==89
summarize Leftist if gnumber_new==89
summarize Reactionary if gnumber_new==89


*Boko Haram*
summarize Warning if gnumber_new==9
tab target_state if gnumber_new==9
summarize Polity2 if gnumber_new==9
summarize PTS if gnumber_new==9
summarize Territory if gnumber_new==9
summarize State_Sponsored if gnumber_new==9
summarize Resources if gnumber_new==9
summarize Separatist if gnumber_new==9
summarize Suicide if gnumber_new==9
summarize Religious if gnumber_new==9
summarize Ethnic if gnumber_new==9
summarize Leftist if gnumber_new==9
summarize Reactionary if gnumber_new==9


*Breton Liberation Front (FLB)*
summarize Warning if gnumber_new==90
tab target_state if gnumber_new==90
summarize Polity2 if gnumber_new==90
summarize PTS if gnumber_new==90
summarize Territory if gnumber_new==90
summarize State_Sponsored if gnumber_new==90
summarize Resources if gnumber_new==90
summarize Separatist if gnumber_new==90
summarize Suicide if gnumber_new==90
summarize Religious if gnumber_new==90
summarize Ethnic if gnumber_new==90
summarize Leftist if gnumber_new==90
summarize Reactionary if gnumber_new==90


*Communist Party of India - Maoist (CPI-Maoist)*
summarize Warning if gnumber_new==10
tab target_state if gnumber_new==10
summarize Polity2 if gnumber_new==10
summarize PTS if gnumber_new==10
summarize Territory if gnumber_new==10
summarize State_Sponsored if gnumber_new==10
summarize Resources if gnumber_new==10
summarize Separatist if gnumber_new==10
summarize Suicide if gnumber_new==10
summarize Religious if gnumber_new==10
summarize Ethnic if gnumber_new==10
summarize Leftist if gnumber_new==10
summarize Reactionary if gnumber_new==10


*Conspiracy of Cells of Fire*
summarize Warning if gnumber_new==91
tab target_state if gnumber_new==91
summarize Polity2 if gnumber_new==91
summarize PTS if gnumber_new==91
summarize Territory if gnumber_new==91
summarize State_Sponsored if gnumber_new==91
summarize Resources if gnumber_new==91
summarize Separatist if gnumber_new==91
summarize Suicide if gnumber_new==91
summarize Religious if gnumber_new==91
summarize Ethnic if gnumber_new==91
summarize Leftist if gnumber_new==91
summarize Reactionary if gnumber_new==91


*Corsican National Liberation Front (FLNC)*
summarize Warning if gnumber_new==11
tab target_state if gnumber_new==11
summarize Polity2 if gnumber_new==11
summarize PTS if gnumber_new==11
summarize Territory if gnumber_new==11
summarize State_Sponsored if gnumber_new==11
summarize Resources if gnumber_new==11
summarize Separatist if gnumber_new==11
summarize Suicide if gnumber_new==11
summarize Religious if gnumber_new==11
summarize Ethnic if gnumber_new==11
summarize Leftist if gnumber_new==11
summarize Reactionary if gnumber_new==11


*Corsican National Liberation Front – Historic Channel*
summarize Warning if gnumber_new==12
tab target_state if gnumber_new==12
summarize Polity2 if gnumber_new==12
summarize PTS if gnumber_new==12
summarize Territory if gnumber_new==12
summarize State_Sponsored if gnumber_new==12
summarize Resources if gnumber_new==12
summarize Separatist if gnumber_new==12
summarize Suicide if gnumber_new==12
summarize Religious if gnumber_new==12
summarize Ethnic if gnumber_new==12
summarize Leftist if gnumber_new==12
summarize Reactionary if gnumber_new==12
 
 
*Democratic Front for the Liberation of Palestine (DFLP)*
summarize Warning if gnumber_new==92
tab target_state if gnumber_new==92
summarize Polity2 if gnumber_new==92
summarize PTS if gnumber_new==92
summarize Territory if gnumber_new==92
summarize State_Sponsored if gnumber_new==92
summarize Resources if gnumber_new==92
summarize Separatist if gnumber_new==92
summarize Suicide if gnumber_new==92
summarize Religious if gnumber_new==92
summarize Ethnic if gnumber_new==92
summarize Leftist if gnumber_new==92
summarize Reactionary if gnumber_new==92


*Dev Sol*
summarize Warning if gnumber_new==13
tab target_state if gnumber_new==13
summarize Polity2 if gnumber_new==13
summarize PTS if gnumber_new==13
summarize Territory if gnumber_new==13
summarize State_Sponsored if gnumber_new==13
summarize Resources if gnumber_new==13
summarize Separatist if gnumber_new==13
summarize Suicide if gnumber_new==13
summarize Religious if gnumber_new==13
summarize Ethnic if gnumber_new==13
summarize Leftist if gnumber_new==13
summarize Reactionary if gnumber_new==13


*Dishmish Regiment*
summarize Warning if gnumber_new==93
tab target_state if gnumber_new==93
summarize Polity2 if gnumber_new==93
summarize PTS if gnumber_new==93
summarize Territory if gnumber_new==93
summarize State_Sponsored if gnumber_new==93
summarize Resources if gnumber_new==93
summarize Separatist if gnumber_new==93
summarize Suicide if gnumber_new==93
summarize Religious if gnumber_new==93
summarize Ethnic if gnumber_new==93
summarize Leftist if gnumber_new==93
summarize Reactionary if gnumber_new==93
 
 
*Donetsk People’s Republic*
summarize Warning if gnumber_new==40
tab target_state if gnumber_new==40
summarize Polity2 if gnumber_new==40
summarize PTS if gnumber_new==40
summarize Territory if gnumber_new==40
summarize State_Sponsored if gnumber_new==40
summarize Resources if gnumber_new==40
summarize Separatist if gnumber_new==40
summarize Suicide if gnumber_new==40
summarize Religious if gnumber_new==40
summarize Ethnic if gnumber_new==40
summarize Leftist if gnumber_new==40
summarize Reactionary if gnumber_new==40
 
 
*Euskadi Ta Askatasuna (ETA)*
summarize Warning if gnumber_new==8
tab target_state if gnumber_new==8
summarize Polity2 if gnumber_new==8
summarize PTS if gnumber_new==8
summarize Territory if gnumber_new==8
summarize State_Sponsored if gnumber_new==8
summarize Resources if gnumber_new==8
summarize Separatist if gnumber_new==8
summarize Suicide if gnumber_new==8
summarize Religious if gnumber_new==8
summarize Ethnic if gnumber_new==8
summarize Leftist if gnumber_new==8
summarize Reactionary if gnumber_new==8
 
 
*Farabundo Marti National Liberation Front (FMLN)*
summarize Warning if gnumber_new==14
tab target_state if gnumber_new==14
summarize Polity2 if gnumber_new==14
summarize PTS if gnumber_new==14
summarize Territory if gnumber_new==14
summarize State_Sponsored if gnumber_new==14
summarize Resources if gnumber_new==14
summarize Separatist if gnumber_new==14
summarize Suicide if gnumber_new==14
summarize Religious if gnumber_new==14
summarize Ethnic if gnumber_new==14
summarize Leftist if gnumber_new==14
summarize Reactionary if gnumber_new==14
 
 
*First of October Antifascist Resistance Group (GRAPO)*
summarize Warning if gnumber_new==15
tab target_state if gnumber_new==15
summarize Polity2 if gnumber_new==15
summarize PTS if gnumber_new==15
summarize Territory if gnumber_new==15
summarize State_Sponsored if gnumber_new==15
summarize Resources if gnumber_new==15
summarize Separatist if gnumber_new==15
summarize Suicide if gnumber_new==15
summarize Religious if gnumber_new==15
summarize Ethnic if gnumber_new==15
summarize Leftist if gnumber_new==15
summarize Reactionary if gnumber_new==15
 
 
*Free Aceh Movement (GAM)*
summarize Warning if gnumber_new==95
tab target_state if gnumber_new==95
summarize Polity2 if gnumber_new==95
summarize PTS if gnumber_new==95
summarize Territory if gnumber_new==95
summarize State_Sponsored if gnumber_new==95
summarize Resources if gnumber_new==95
summarize Separatist if gnumber_new==95
summarize Suicide if gnumber_new==95
summarize Religious if gnumber_new==95
summarize Ethnic if gnumber_new==95
summarize Leftist if gnumber_new==95
summarize Reactionary if gnumber_new==95
 
 
*Free Galician People’s Guerrilla Army*
summarize Warning if gnumber_new==96
tab target_state if gnumber_new==96
summarize Polity2 if gnumber_new==96
summarize PTS if gnumber_new==96
summarize Territory if gnumber_new==96
summarize State_Sponsored if gnumber_new==96
summarize Resources if gnumber_new==96
summarize Separatist if gnumber_new==96
summarize Suicide if gnumber_new==96
summarize Religious if gnumber_new==96
summarize Ethnic if gnumber_new==96
summarize Leftist if gnumber_new==96
summarize Reactionary if gnumber_new==96
 
 
*Free Syrian Army*
summarize Warning if gnumber_new==52
tab target_state if gnumber_new==52
summarize Polity2 if gnumber_new==52
summarize PTS if gnumber_new==52
summarize Territory if gnumber_new==52
summarize State_Sponsored if gnumber_new==52
summarize Resources if gnumber_new==52
summarize Separatist if gnumber_new==52
summarize Suicide if gnumber_new==52
summarize Religious if gnumber_new==52
summarize Ethnic if gnumber_new==52
summarize Leftist if gnumber_new==52
summarize Reactionary if gnumber_new==52


*Garo National Liberation Army*
summarize Warning if gnumber_new==97
tab target_state if gnumber_new==97
summarize Polity2 if gnumber_new==97
summarize PTS if gnumber_new==97
summarize Territory if gnumber_new==97
summarize State_Sponsored if gnumber_new==97
summarize Resources if gnumber_new==97
summarize Separatist if gnumber_new==97
summarize Suicide if gnumber_new==97
summarize Religious if gnumber_new==97
summarize Ethnic if gnumber_new==97
summarize Leftist if gnumber_new==97
summarize Reactionary if gnumber_new==97
 
 
*Great Eastern Islamic Raiders Front (IBDA-C)*
summarize Warning if gnumber_new==98
tab target_state if gnumber_new==98
summarize Polity2 if gnumber_new==98
summarize PTS if gnumber_new==98
summarize Territory if gnumber_new==98
summarize State_Sponsored if gnumber_new==98
summarize Resources if gnumber_new==98
summarize Separatist if gnumber_new==98
summarize Suicide if gnumber_new==98
summarize Religious if gnumber_new==98
summarize Ethnic if gnumber_new==98
summarize Leftist if gnumber_new==98
summarize Reactionary if gnumber_new==98
 
 
*Guerrilla Army of the Poor (EGP)*
summarize Warning if gnumber_new==99
tab target_state if gnumber_new==99
summarize Polity2 if gnumber_new==99
summarize PTS if gnumber_new==99
summarize Territory if gnumber_new==99
summarize State_Sponsored if gnumber_new==99
summarize Resources if gnumber_new==99
summarize Separatist if gnumber_new==99
summarize Suicide if gnumber_new==99
summarize Religious if gnumber_new==99
summarize Ethnic if gnumber_new==99
summarize Leftist if gnumber_new==99
summarize Reactionary if gnumber_new==99
 
 
*Hamas (Islamic Resistance Movement)*
summarize Warning if gnumber_new==17
tab target_state if gnumber_new==17
summarize Polity2 if gnumber_new==17
summarize PTS if gnumber_new==17
summarize Territory if gnumber_new==17
summarize State_Sponsored if gnumber_new==17
summarize Resources if gnumber_new==17
summarize Separatist if gnumber_new==17
summarize Suicide if gnumber_new==17
summarize Religious if gnumber_new==17
summarize Ethnic if gnumber_new==17
summarize Leftist if gnumber_new==17
summarize Reactionary if gnumber_new==17


*Haqqani Network*
summarize Warning if gnumber_new==54
tab target_state if gnumber_new==54
summarize Polity2 if gnumber_new==54
summarize PTS if gnumber_new==54
summarize Territory if gnumber_new==54
summarize State_Sponsored if gnumber_new==54
summarize Resources if gnumber_new==54
summarize Separatist if gnumber_new==54
summarize Suicide if gnumber_new==54
summarize Religious if gnumber_new==54
summarize Ethnic if gnumber_new==54
summarize Leftist if gnumber_new==54
summarize Reactionary if gnumber_new==54
 
 
*Hizb-I-Islami*
summarize Warning if gnumber_new==100
tab target_state if gnumber_new==100
summarize Polity2 if gnumber_new==100
summarize PTS if gnumber_new==100
summarize Territory if gnumber_new==100
summarize State_Sponsored if gnumber_new==100
summarize Resources if gnumber_new==100
summarize Separatist if gnumber_new==100
summarize Suicide if gnumber_new==100
summarize Religious if gnumber_new==100
summarize Ethnic if gnumber_new==100
summarize Leftist if gnumber_new==100
summarize Reactionary if gnumber_new==100


*Hezbollah (Hizballah)*
summarize Warning if gnumber_new==18
tab target_state if gnumber_new==18
summarize Polity2 if gnumber_new==18
summarize PTS if gnumber_new==18
summarize Territory if gnumber_new==18
summarize State_Sponsored if gnumber_new==18
summarize Resources if gnumber_new==18
summarize Separatist if gnumber_new==18
summarize Suicide if gnumber_new==18
summarize Religious if gnumber_new==18
summarize Ethnic if gnumber_new==18
summarize Leftist if gnumber_new==18
summarize Reactionary if gnumber_new==18


*Hizbul Mujahideen (HM)*
summarize Warning if gnumber_new==55
tab target_state if gnumber_new==55
summarize Polity2 if gnumber_new==55
summarize PTS if gnumber_new==55
summarize Territory if gnumber_new==55
summarize State_Sponsored if gnumber_new==55
summarize Resources if gnumber_new==55
summarize Separatist if gnumber_new==55
summarize Suicide if gnumber_new==55
summarize Religious if gnumber_new==55
summarize Ethnic if gnumber_new==55
summarize Leftist if gnumber_new==55
summarize Reactionary if gnumber_new==55


*Indian Mujahideen*
summarize Warning if gnumber_new==101
tab target_state if gnumber_new==101
summarize Polity2 if gnumber_new==101
summarize PTS if gnumber_new==101
summarize Territory if gnumber_new==101
summarize State_Sponsored if gnumber_new==101
summarize Resources if gnumber_new==101
summarize Separatist if gnumber_new==101
summarize Suicide if gnumber_new==101
summarize Religious if gnumber_new==101
summarize Ethnic if gnumber_new==101
summarize Leftist if gnumber_new==101
summarize Reactionary if gnumber_new==101


*Informal Anarchist Federation*
summarize Warning if gnumber_new==102
tab target_state if gnumber_new==102
summarize Polity2 if gnumber_new==102
summarize PTS if gnumber_new==102
summarize Territory if gnumber_new==102
summarize State_Sponsored if gnumber_new==102
summarize Resources if gnumber_new==102
summarize Separatist if gnumber_new==102
summarize Suicide if gnumber_new==102
summarize Religious if gnumber_new==102
summarize Ethnic if gnumber_new==102
summarize Leftist if gnumber_new==102
summarize Reactionary if gnumber_new==102
 
 
*Iparretarrak (IK)*
summarize Warning if gnumber_new==103
tab target_state if gnumber_new==103
summarize Polity2 if gnumber_new==103
summarize PTS if gnumber_new==103
summarize Territory if gnumber_new==103
summarize State_Sponsored if gnumber_new==103
summarize Resources if gnumber_new==103
summarize Separatist if gnumber_new==103
summarize Suicide if gnumber_new==103
summarize Religious if gnumber_new==103
summarize Ethnic if gnumber_new==103
summarize Leftist if gnumber_new==103
summarize Reactionary if gnumber_new==103
 
 
*Irish National Liberation Army (INLA)*
summarize Warning if gnumber_new==104
tab target_state if gnumber_new==104
summarize Polity2 if gnumber_new==104
summarize PTS if gnumber_new==104
summarize Territory if gnumber_new==104
summarize State_Sponsored if gnumber_new==104
summarize Resources if gnumber_new==104
summarize Separatist if gnumber_new==104
summarize Suicide if gnumber_new==104
summarize Religious if gnumber_new==104
summarize Ethnic if gnumber_new==104
summarize Leftist if gnumber_new==104
summarize Reactionary if gnumber_new==104
 
 
*Irish Republican Army (IRA)*
summarize Warning if gnumber_new==19
tab target_state if gnumber_new==19
summarize Polity2 if gnumber_new==19
summarize PTS if gnumber_new==19
summarize Territory if gnumber_new==19
summarize State_Sponsored if gnumber_new==19
summarize Resources if gnumber_new==19
summarize Separatist if gnumber_new==19
summarize Suicide if gnumber_new==19
summarize Religious if gnumber_new==19
summarize Ethnic if gnumber_new==19
summarize Leftist if gnumber_new==19
summarize Reactionary if gnumber_new==19


*Islamic Front (Syria)*
summarize Warning if gnumber_new==105
tab target_state if gnumber_new==105
summarize Polity2 if gnumber_new==105
summarize PTS if gnumber_new==105
summarize Territory if gnumber_new==105
summarize State_Sponsored if gnumber_new==105
summarize Resources if gnumber_new==105
summarize Separatist if gnumber_new==105
summarize Suicide if gnumber_new==105
summarize Religious if gnumber_new==105
summarize Ethnic if gnumber_new==105
summarize Leftist if gnumber_new==105
summarize Reactionary if gnumber_new==105


*Islamic State of Iraq and the Levant (ISIL)*
summarize Warning if gnumber_new==41
tab target_state if gnumber_new==41
summarize Polity2 if gnumber_new==41
summarize PTS if gnumber_new==41
summarize Territory if gnumber_new==41
summarize State_Sponsored if gnumber_new==41
summarize Resources if gnumber_new==41
summarize Separatist if gnumber_new==41
summarize Suicide if gnumber_new==41
summarize Religious if gnumber_new==41
summarize Ethnic if gnumber_new==41
summarize Leftist if gnumber_new==41
summarize Reactionary if gnumber_new==41
 
 
*Jamaat-E-Islami (Bangladesh)*
summarize Warning if gnumber_new==106
tab target_state if gnumber_new==106
summarize Polity2 if gnumber_new==106
summarize PTS if gnumber_new==106
summarize Territory if gnumber_new==106
summarize State_Sponsored if gnumber_new==106
summarize Resources if gnumber_new==106
summarize Separatist if gnumber_new==106
summarize Suicide if gnumber_new==106
summarize Religious if gnumber_new==106
summarize Ethnic if gnumber_new==106
summarize Leftist if gnumber_new==106
summarize Reactionary if gnumber_new==106
 
 
*Jaysh al-Islam (Syria)*
summarize Warning if gnumber_new==107
tab target_state if gnumber_new==107
summarize Polity2 if gnumber_new==107
summarize PTS if gnumber_new==107
summarize Territory if gnumber_new==107
summarize State_Sponsored if gnumber_new==107
summarize Resources if gnumber_new==107
summarize Separatist if gnumber_new==107
summarize Suicide if gnumber_new==107
summarize Religious if gnumber_new==107
summarize Ethnic if gnumber_new==107
summarize Leftist if gnumber_new==107
summarize Reactionary if gnumber_new==107


*Jemaah Islamiya (JI)*
summarize Warning if gnumber_new==57
tab target_state if gnumber_new==57
summarize Polity2 if gnumber_new==57
summarize PTS if gnumber_new==57
summarize Territory if gnumber_new==57
summarize State_Sponsored if gnumber_new==57
summarize Resources if gnumber_new==57
summarize Separatist if gnumber_new==57
summarize Suicide if gnumber_new==57
summarize Religious if gnumber_new==57
summarize Ethnic if gnumber_new==57
summarize Leftist if gnumber_new==57
summarize Reactionary if gnumber_new==57


*Jewish Defense League (JDL)*
summarize Warning if gnumber_new==108
tab target_state if gnumber_new==108
summarize Polity2 if gnumber_new==108
summarize PTS if gnumber_new==108
summarize Territory if gnumber_new==108
summarize State_Sponsored if gnumber_new==108
summarize Resources if gnumber_new==108
summarize Separatist if gnumber_new==108
summarize Suicide if gnumber_new==108
summarize Religious if gnumber_new==108
summarize Ethnic if gnumber_new==108
summarize Leftist if gnumber_new==108
summarize Reactionary if gnumber_new==108


*Kangleipak Communist Party (KCP)*
summarize Warning if gnumber_new==109
tab target_state if gnumber_new==109
summarize Polity2 if gnumber_new==109
summarize PTS if gnumber_new==109
summarize Territory if gnumber_new==109
summarize State_Sponsored if gnumber_new==109
summarize Resources if gnumber_new==109
summarize Separatist if gnumber_new==109
summarize Suicide if gnumber_new==109
summarize Religious if gnumber_new==109
summarize Ethnic if gnumber_new==109
summarize Leftist if gnumber_new==109
summarize Reactionary if gnumber_new==109


*Karen National Union*
summarize Warning if gnumber_new==58
tab target_state if gnumber_new==58
summarize Polity2 if gnumber_new==58
summarize PTS if gnumber_new==58
summarize Territory if gnumber_new==58
summarize State_Sponsored if gnumber_new==58
summarize Resources if gnumber_new==58
summarize Separatist if gnumber_new==58
summarize Suicide if gnumber_new==58
summarize Religious if gnumber_new==58
summarize Ethnic if gnumber_new==58
summarize Leftist if gnumber_new==58
summarize Reactionary if gnumber_new==58

*Khmer Rouge*
summarize Warning if gnumber_new==59
tab target_state if gnumber_new==59
summarize Polity2 if gnumber_new==59
summarize PTS if gnumber_new==59
summarize Territory if gnumber_new==59
summarize State_Sponsored if gnumber_new==59
summarize Resources if gnumber_new==59
summarize Separatist if gnumber_new==59
summarize Suicide if gnumber_new==59
summarize Religious if gnumber_new==59
summarize Ethnic if gnumber_new==59
summarize Leftist if gnumber_new==59
summarize Reactionary if gnumber_new==59


*Khorasan Chapter of the Islamic State*
summarize Warning if gnumber_new==60
tab target_state if gnumber_new==60
summarize Polity2 if gnumber_new==60
summarize PTS if gnumber_new==60
summarize Territory if gnumber_new==60
summarize State_Sponsored if gnumber_new==60
summarize Resources if gnumber_new==60
summarize Separatist if gnumber_new==60
summarize Suicide if gnumber_new==60
summarize Religious if gnumber_new==60
summarize Ethnic if gnumber_new==60
summarize Leftist if gnumber_new==60
summarize Reactionary if gnumber_new==60


*Kurdistan Workers’ Party (PKK)*
summarize Warning if gnumber_new==20
tab target_state if gnumber_new==20
summarize Polity2 if gnumber_new==20
summarize PTS if gnumber_new==20
summarize Territory if gnumber_new==20
summarize State_Sponsored if gnumber_new==20
summarize Resources if gnumber_new==20
summarize Separatist if gnumber_new==20
summarize Suicide if gnumber_new==20
summarize Religious if gnumber_new==20
summarize Ethnic if gnumber_new==20
summarize Leftist if gnumber_new==20
summarize Reactionary if gnumber_new==20


*Lashkar-e-Islam (Pakistan)*
summarize Warning if gnumber_new==111
tab target_state if gnumber_new==111
summarize Polity2 if gnumber_new==111
summarize PTS if gnumber_new==111
summarize Territory if gnumber_new==111
summarize State_Sponsored if gnumber_new==111
summarize Resources if gnumber_new==111
summarize Separatist if gnumber_new==111
summarize Suicide if gnumber_new==111
summarize Religious if gnumber_new==111
summarize Ethnic if gnumber_new==111
summarize Leftist if gnumber_new==111
summarize Reactionary if gnumber_new==111


*Lashkar-e-Jhangvi*
summarize Warning if gnumber_new==112
tab target_state if gnumber_new==112
summarize Polity2 if gnumber_new==112
summarize PTS if gnumber_new==112
summarize Territory if gnumber_new==112
summarize State_Sponsored if gnumber_new==112
summarize Resources if gnumber_new==112
summarize Separatist if gnumber_new==112
summarize Suicide if gnumber_new==112
summarize Religious if gnumber_new==112
summarize Ethnic if gnumber_new==112
summarize Leftist if gnumber_new==112
summarize Reactionary if gnumber_new==112


*Lashkar-e-Taiba (LeT)*
summarize Warning if gnumber_new==61
tab target_state if gnumber_new==61
summarize Polity2 if gnumber_new==61
summarize PTS if gnumber_new==61
summarize Territory if gnumber_new==61
summarize State_Sponsored if gnumber_new==61
summarize Resources if gnumber_new==61
summarize Separatist if gnumber_new==61
summarize Suicide if gnumber_new==61
summarize Religious if gnumber_new==61
summarize Ethnic if gnumber_new==61
summarize Leftist if gnumber_new==61
summarize Reactionary if gnumber_new==61


*Liberation Tigers of Tamil Eelam (LTTE)*
summarize Warning if gnumber_new==21
tab target_state if gnumber_new==21
summarize Polity2 if gnumber_new==21
summarize PTS if gnumber_new==21
summarize Territory if gnumber_new==21
summarize State_Sponsored if gnumber_new==21
summarize Resources if gnumber_new==21
summarize Separatist if gnumber_new==21
summarize Suicide if gnumber_new==21
summarize Religious if gnumber_new==21
summarize Ethnic if gnumber_new==21
summarize Leftist if gnumber_new==21
summarize Reactionary if gnumber_new==21


*Lorenzo Zelaya Revolutionary Front (LZRF)*
summarize Warning if gnumber_new==113
tab target_state if gnumber_new==113
summarize Polity2 if gnumber_new==113
summarize PTS if gnumber_new==113
summarize Territory if gnumber_new==113
summarize State_Sponsored if gnumber_new==113
summarize Resources if gnumber_new==113
summarize Separatist if gnumber_new==113
summarize Suicide if gnumber_new==113
summarize Religious if gnumber_new==113
summarize Ethnic if gnumber_new==113
summarize Leftist if gnumber_new==113
summarize Reactionary if gnumber_new==113


*Luhansk People’s Republic*
summarize Warning if gnumber_new==42
tab target_state if gnumber_new==42
summarize Polity2 if gnumber_new==42
summarize PTS if gnumber_new==42
summarize Territory if gnumber_new==42
summarize State_Sponsored if gnumber_new==42
summarize Resources if gnumber_new==42
summarize Separatist if gnumber_new==42
summarize Suicide if gnumber_new==42
summarize Religious if gnumber_new==42
summarize Ethnic if gnumber_new==42
summarize Leftist if gnumber_new==42
summarize Reactionary if gnumber_new==42


*Manuel Rodriguez Patriotic Front (FPMR)*
summarize Warning if gnumber_new==23
tab target_state if gnumber_new==23
summarize Polity2 if gnumber_new==23
summarize PTS if gnumber_new==23
summarize Territory if gnumber_new==23
summarize State_Sponsored if gnumber_new==23
summarize Resources if gnumber_new==23
summarize Separatist if gnumber_new==23
summarize Suicide if gnumber_new==23
summarize Religious if gnumber_new==23
summarize Ethnic if gnumber_new==23
summarize Leftist if gnumber_new==23
summarize Reactionary if gnumber_new==23


*Montoneros (Argentina)*
summarize Warning if gnumber_new==114
tab target_state if gnumber_new==114
summarize Polity2 if gnumber_new==114
summarize PTS if gnumber_new==114
summarize Territory if gnumber_new==114
summarize State_Sponsored if gnumber_new==114
summarize Resources if gnumber_new==114
summarize Separatist if gnumber_new==114
summarize Suicide if gnumber_new==114
summarize Religious if gnumber_new==114
summarize Ethnic if gnumber_new==114
summarize Leftist if gnumber_new==114
summarize Reactionary if gnumber_new==114
 
 
*Moro Islamic Liberation Front (MILF)*
summarize Warning if gnumber_new==24
tab target_state if gnumber_new==24
summarize Polity2 if gnumber_new==24
summarize PTS if gnumber_new==24
summarize Territory if gnumber_new==24
summarize State_Sponsored if gnumber_new==24
summarize Resources if gnumber_new==24
summarize Separatist if gnumber_new==24
summarize Suicide if gnumber_new==24
summarize Religious if gnumber_new==24
summarize Ethnic if gnumber_new==24
summarize Leftist if gnumber_new==24
summarize Reactionary if gnumber_new==24


*Moro National Liberation Front (MNLF)*
summarize Warning if gnumber_new==62
tab target_state if gnumber_new==62
summarize Polity2 if gnumber_new==62
summarize PTS if gnumber_new==62
summarize Territory if gnumber_new==62
summarize State_Sponsored if gnumber_new==62
summarize Resources if gnumber_new==62
summarize Separatist if gnumber_new==62
summarize Suicide if gnumber_new==62
summarize Religious if gnumber_new==62
summarize Ethnic if gnumber_new==62
summarize Leftist if gnumber_new==62
summarize Reactionary if gnumber_new==62


*Movement for Oneness and Jihad in West Africa (MUJAO)*
summarize Warning if gnumber_new==115
tab target_state if gnumber_new==115
summarize Polity2 if gnumber_new==115
summarize PTS if gnumber_new==115
summarize Territory if gnumber_new==115
summarize State_Sponsored if gnumber_new==115
summarize Resources if gnumber_new==115
summarize Separatist if gnumber_new==115
summarize Suicide if gnumber_new==115
summarize Religious if gnumber_new==115
summarize Ethnic if gnumber_new==115
summarize Leftist if gnumber_new==115
summarize Reactionary if gnumber_new==115
 
 
*Movement for the Emancipation of the Niger Delta (MEND)*
summarize Warning if gnumber_new==116
tab target_state if gnumber_new==116
summarize Polity2 if gnumber_new==116
summarize PTS if gnumber_new==116
summarize Territory if gnumber_new==116
summarize State_Sponsored if gnumber_new==116
summarize Resources if gnumber_new==116
summarize Separatist if gnumber_new==116
summarize Suicide if gnumber_new==116
summarize Religious if gnumber_new==116
summarize Ethnic if gnumber_new==116
summarize Leftist if gnumber_new==116
summarize Reactionary if gnumber_new==116
 
 
*M-19 (Movement of April 19)*
summarize Warning if gnumber_new==22
tab target_state if gnumber_new==22
summarize Polity2 if gnumber_new==22
summarize PTS if gnumber_new==22
summarize Territory if gnumber_new==22
summarize State_Sponsored if gnumber_new==22
summarize Resources if gnumber_new==22
summarize Separatist if gnumber_new==22
summarize Suicide if gnumber_new==22
summarize Religious if gnumber_new==22
summarize Ethnic if gnumber_new==22
summarize Leftist if gnumber_new==22
summarize Reactionary if gnumber_new==22


*Movement of the Revolutionary Left (MIR) (Chile)
summarize Warning if gnumber_new==25
tab target_state if gnumber_new==25
summarize Polity2 if gnumber_new==25
summarize PTS if gnumber_new==25
summarize Territory if gnumber_new==25
summarize State_Sponsored if gnumber_new==25
summarize Resources if gnumber_new==25
summarize Separatist if gnumber_new==25
summarize Suicide if gnumber_new==25
summarize Religious if gnumber_new==25
summarize Ethnic if gnumber_new==25
summarize Leftist if gnumber_new==25
summarize Reactionary if gnumber_new==25


*Mozambique National Resistance Movement (MNR)*
summarize Warning if gnumber_new==117
tab target_state if gnumber_new==117
summarize Polity2 if gnumber_new==117
summarize PTS if gnumber_new==117
summarize Territory if gnumber_new==117
summarize State_Sponsored if gnumber_new==117
summarize Resources if gnumber_new==117
summarize Separatist if gnumber_new==117
summarize Suicide if gnumber_new==117
summarize Religious if gnumber_new==117
summarize Ethnic if gnumber_new==117
summarize Leftist if gnumber_new==117
summarize Reactionary if gnumber_new==117


*Mujahedin-e Khalq (MEK)*
summarize Warning if gnumber_new==63
tab target_state if gnumber_new==63
summarize Polity2 if gnumber_new==63
summarize PTS if gnumber_new==63
summarize Territory if gnumber_new==63
summarize State_Sponsored if gnumber_new==63
summarize Resources if gnumber_new==63
summarize Separatist if gnumber_new==63
summarize Suicide if gnumber_new==63
summarize Religious if gnumber_new==63
summarize Ethnic if gnumber_new==63
summarize Leftist if gnumber_new==63
summarize Reactionary if gnumber_new==63


*National Democratic Front of Bodoland (NDFB)*
summarize Warning if gnumber_new==64
tab target_state if gnumber_new==64
summarize Polity2 if gnumber_new==64
summarize PTS if gnumber_new==64
summarize Territory if gnumber_new==64
summarize State_Sponsored if gnumber_new==64
summarize Resources if gnumber_new==64
summarize Separatist if gnumber_new==64
summarize Suicide if gnumber_new==64
summarize Religious if gnumber_new==64
summarize Ethnic if gnumber_new==64
summarize Leftist if gnumber_new==64
summarize Reactionary if gnumber_new==64


*National Liberation Army of Colombia (ELN)*
summarize Warning if gnumber_new==26
tab target_state if gnumber_new==26
summarize Polity2 if gnumber_new==26
summarize PTS if gnumber_new==26
summarize Territory if gnumber_new==26
summarize State_Sponsored if gnumber_new==26
summarize Resources if gnumber_new==26
summarize Separatist if gnumber_new==26
summarize Suicide if gnumber_new==26
summarize Religious if gnumber_new==26
summarize Ethnic if gnumber_new==26
summarize Leftist if gnumber_new==26
summarize Reactionary if gnumber_new==26
 
 
*National Union for the Total Independence of Angola (UNITA)*
summarize Warning if gnumber_new==27
tab target_state if gnumber_new==27
summarize Polity2 if gnumber_new==27
summarize PTS if gnumber_new==27
summarize Territory if gnumber_new==27
summarize State_Sponsored if gnumber_new==27
summarize Resources if gnumber_new==27
summarize Separatist if gnumber_new==27
summarize Suicide if gnumber_new==27
summarize Religious if gnumber_new==27
summarize Ethnic if gnumber_new==27
summarize Leftist if gnumber_new==27
summarize Reactionary if gnumber_new==27
 
 
*New People’s Army (NPA)*
summarize Warning if gnumber_new==28
tab target_state if gnumber_new==28
summarize Polity2 if gnumber_new==28
summarize PTS if gnumber_new==28
summarize Territory if gnumber_new==28
summarize State_Sponsored if gnumber_new==28
summarize Resources if gnumber_new==28
summarize Separatist if gnumber_new==28
summarize Suicide if gnumber_new==28
summarize Religious if gnumber_new==28
summarize Ethnic if gnumber_new==28
summarize Leftist if gnumber_new==28
summarize Reactionary if gnumber_new==28


*New World Liberation Front (NWLF)*
summarize Warning if gnumber_new==65
tab target_state if gnumber_new==65
summarize Polity2 if gnumber_new==65
summarize PTS if gnumber_new==65
summarize Territory if gnumber_new==65
summarize State_Sponsored if gnumber_new==65
summarize Resources if gnumber_new==65
summarize Separatist if gnumber_new==65
summarize Suicide if gnumber_new==65
summarize Religious if gnumber_new==65
summarize Ethnic if gnumber_new==65
summarize Leftist if gnumber_new==65
summarize Reactionary if gnumber_new==65


*Nicaraguan Democratic Force (FDN)*
summarize Warning if gnumber_new==29
tab target_state if gnumber_new==29
summarize Polity2 if gnumber_new==29
summarize PTS if gnumber_new==29
summarize Territory if gnumber_new==29
summarize State_Sponsored if gnumber_new==29
summarize Resources if gnumber_new==29
summarize Separatist if gnumber_new==29
summarize Suicide if gnumber_new==29
summarize Religious if gnumber_new==29
summarize Ethnic if gnumber_new==29
summarize Leftist if gnumber_new==29
summarize Reactionary if gnumber_new==29


*Niger Delta Avengers (NDA)*
summarize Warning if gnumber_new==137
tab target_state if gnumber_new==137
summarize Polity2 if gnumber_new==137
summarize PTS if gnumber_new==137
summarize Territory if gnumber_new==137
summarize State_Sponsored if gnumber_new==137
summarize Resources if gnumber_new==137
summarize Separatist if gnumber_new==137
summarize Suicide if gnumber_new==137
summarize Religious if gnumber_new==137
summarize Ethnic if gnumber_new==137
summarize Leftist if gnumber_new==137
summarize Reactionary if gnumber_new==137


*November 17 Revolutionary Organization (N17RO)*
summarize Warning if gnumber_new==66
tab target_state if gnumber_new==66
summarize Polity2 if gnumber_new==66
summarize PTS if gnumber_new==66
summarize Territory if gnumber_new==66
summarize State_Sponsored if gnumber_new==66
summarize Resources if gnumber_new==66
summarize Separatist if gnumber_new==66
summarize Suicide if gnumber_new==66
summarize Religious if gnumber_new==66
summarize Ethnic if gnumber_new==66
summarize Leftist if gnumber_new==66
summarize Reactionary if gnumber_new==66


*Oglaigh na hEireann*
summarize Warning if gnumber_new==118
tab target_state if gnumber_new==118
summarize Polity2 if gnumber_new==118
summarize PTS if gnumber_new==118
summarize Territory if gnumber_new==118
summarize State_Sponsored if gnumber_new==118
summarize Resources if gnumber_new==118
summarize Separatist if gnumber_new==118
summarize Suicide if gnumber_new==118
summarize Religious if gnumber_new==118
summarize Ethnic if gnumber_new==118
summarize Leftist if gnumber_new==118
summarize Reactionary if gnumber_new==118


*Omega-7*
summarize Warning if gnumber_new==119
tab target_state if gnumber_new==119
summarize Polity2 if gnumber_new==119
summarize PTS if gnumber_new==119
summarize Territory if gnumber_new==119
summarize State_Sponsored if gnumber_new==119
summarize Resources if gnumber_new==119
summarize Separatist if gnumber_new==119
summarize Suicide if gnumber_new==119
summarize Religious if gnumber_new==119
summarize Ethnic if gnumber_new==119
summarize Leftist if gnumber_new==119
summarize Reactionary if gnumber_new==119


*Palestine Liberation Organization (PLO)*
summarize Warning if gnumber_new==30
tab target_state if gnumber_new==30
summarize Polity2 if gnumber_new==30
summarize PTS if gnumber_new==30
summarize Territory if gnumber_new==30
summarize State_Sponsored if gnumber_new==30
summarize Resources if gnumber_new==30
summarize Separatist if gnumber_new==30
summarize Suicide if gnumber_new==30
summarize Religious if gnumber_new==30
summarize Ethnic if gnumber_new==30
summarize Leftist if gnumber_new==30
summarize Reactionary if gnumber_new==30


*Palestinian Islamic Jihad*
summarize Warning if gnumber_new==31
tab target_state if gnumber_new==31
summarize Polity2 if gnumber_new==31
summarize PTS if gnumber_new==31
summarize Territory if gnumber_new==31
summarize State_Sponsored if gnumber_new==31
summarize Resources if gnumber_new==31
summarize Separatist if gnumber_new==31
summarize Suicide if gnumber_new==31
summarize Religious if gnumber_new==31
summarize Ethnic if gnumber_new==31
summarize Leftist if gnumber_new==31
summarize Reactionary if gnumber_new==31


*Pattani United Liberation Organization (PULO)*
summarize Warning if gnumber_new==120
tab target_state if gnumber_new==120
summarize Polity2 if gnumber_new==120
summarize PTS if gnumber_new==120
summarize Territory if gnumber_new==120
summarize State_Sponsored if gnumber_new==120
summarize Resources if gnumber_new==120
summarize Separatist if gnumber_new==120
summarize Suicide if gnumber_new==120
summarize Religious if gnumber_new==120
summarize Ethnic if gnumber_new==120
summarize Leftist if gnumber_new==120
summarize Reactionary if gnumber_new==120


*People’s Liberation Army (India)*
summarize Warning if gnumber_new==67
tab target_state if gnumber_new==67
summarize Polity2 if gnumber_new==67
summarize PTS if gnumber_new==67
summarize Territory if gnumber_new==67
summarize State_Sponsored if gnumber_new==67
summarize Resources if gnumber_new==67
summarize Separatist if gnumber_new==67
summarize Suicide if gnumber_new==67
summarize Religious if gnumber_new==67
summarize Ethnic if gnumber_new==67
summarize Leftist if gnumber_new==67
summarize Reactionary if gnumber_new==67


*People’s Liberation Front (JVP)*
summarize Warning if gnumber_new==69
tab target_state if gnumber_new==69
summarize Polity2 if gnumber_new==69
summarize PTS if gnumber_new==69
summarize Territory if gnumber_new==69
summarize State_Sponsored if gnumber_new==69
summarize Resources if gnumber_new==69
summarize Separatist if gnumber_new==69
summarize Suicide if gnumber_new==69
summarize Religious if gnumber_new==69
summarize Ethnic if gnumber_new==69
summarize Leftist if gnumber_new==69
summarize Reactionary if gnumber_new==69


*People’s War Group (PWG)*
summarize Warning if gnumber_new==70
tab target_state if gnumber_new==70
summarize Polity2 if gnumber_new==70
summarize PTS if gnumber_new==70
summarize Territory if gnumber_new==70
summarize State_Sponsored if gnumber_new==70
summarize Resources if gnumber_new==70
summarize Separatist if gnumber_new==70
summarize Suicide if gnumber_new==70
summarize Religious if gnumber_new==70
summarize Ethnic if gnumber_new==70
summarize Leftist if gnumber_new==70
summarize Reactionary if gnumber_new==70


*Popular Front for the Liberation of Palestine (PFLP)*
summarize Warning if gnumber_new==71
tab target_state if gnumber_new==71
summarize Polity2 if gnumber_new==71
summarize PTS if gnumber_new==71
summarize Territory if gnumber_new==71
summarize State_Sponsored if gnumber_new==71
summarize Resources if gnumber_new==71
summarize Separatist if gnumber_new==71
summarize Suicide if gnumber_new==71
summarize Religious if gnumber_new==71
summarize Ethnic if gnumber_new==71
summarize Leftist if gnumber_new==71
summarize Reactionary if gnumber_new==71


*Popular Liberation Army (EPL)*
summarize Warning if gnumber_new==122
tab target_state if gnumber_new==122
summarize Polity2 if gnumber_new==122
summarize PTS if gnumber_new==122
summarize Territory if gnumber_new==122
summarize State_Sponsored if gnumber_new==122
summarize Resources if gnumber_new==122
summarize Separatist if gnumber_new==122
summarize Suicide if gnumber_new==122
summarize Religious if gnumber_new==122
summarize Ethnic if gnumber_new==122
summarize Leftist if gnumber_new==122
summarize Reactionary if gnumber_new==122


*Popular Resistance Committees*
summarize Warning if gnumber_new==123
tab target_state if gnumber_new==123
summarize Polity2 if gnumber_new==123
summarize PTS if gnumber_new==123
summarize Territory if gnumber_new==123
summarize State_Sponsored if gnumber_new==123
summarize Resources if gnumber_new==123
summarize Separatist if gnumber_new==123
summarize Suicide if gnumber_new==123
summarize Religious if gnumber_new==123
summarize Ethnic if gnumber_new==123
summarize Leftist if gnumber_new==123
summarize Reactionary if gnumber_new==123


*Real Irish Republican Army (RIRA)*
summarize Warning if gnumber_new==124
tab target_state if gnumber_new==124
summarize Polity2 if gnumber_new==124
summarize PTS if gnumber_new==124
summarize Territory if gnumber_new==124
summarize State_Sponsored if gnumber_new==124
summarize Resources if gnumber_new==124
summarize Separatist if gnumber_new==124
summarize Suicide if gnumber_new==124
summarize Religious if gnumber_new==124
summarize Ethnic if gnumber_new==124
summarize Leftist if gnumber_new==124
summarize Reactionary if gnumber_new==124


*Red Army Faction (RAF)*
summarize Warning if gnumber_new==125
tab target_state if gnumber_new==125
summarize Polity2 if gnumber_new==125
summarize PTS if gnumber_new==125
summarize Territory if gnumber_new==125
summarize State_Sponsored if gnumber_new==125
summarize Resources if gnumber_new==125
summarize Separatist if gnumber_new==125
summarize Suicide if gnumber_new==125
summarize Religious if gnumber_new==125
summarize Ethnic if gnumber_new==125
summarize Leftist if gnumber_new==125
summarize Reactionary if gnumber_new==125


*Red Brigades*
summarize Warning if gnumber_new==126
tab target_state if gnumber_new==126
summarize Polity2 if gnumber_new==126
summarize PTS if gnumber_new==126
summarize Territory if gnumber_new==126
summarize State_Sponsored if gnumber_new==126
summarize Resources if gnumber_new==126
summarize Separatist if gnumber_new==126
summarize Suicide if gnumber_new==126
summarize Religious if gnumber_new==126
summarize Ethnic if gnumber_new==126
summarize Leftist if gnumber_new==126
summarize Reactionary if gnumber_new==126


*Resistenza*
summarize Warning if gnumber_new==72
tab target_state if gnumber_new==72
summarize Polity2 if gnumber_new==72
summarize PTS if gnumber_new==72
summarize Territory if gnumber_new==72
summarize State_Sponsored if gnumber_new==72
summarize Resources if gnumber_new==72
summarize Separatist if gnumber_new==72
summarize Suicide if gnumber_new==72
summarize Religious if gnumber_new==72
summarize Ethnic if gnumber_new==72
summarize Leftist if gnumber_new==72
summarize Reactionary if gnumber_new==72


*Revolutionary Armed Forces of Colombia (FARC)*
summarize Warning if gnumber_new==32
tab target_state if gnumber_new==32
summarize Polity2 if gnumber_new==32
summarize PTS if gnumber_new==32
summarize Territory if gnumber_new==32
summarize State_Sponsored if gnumber_new==32
summarize Resources if gnumber_new==32
summarize Separatist if gnumber_new==32
summarize Suicide if gnumber_new==32
summarize Religious if gnumber_new==32
summarize Ethnic if gnumber_new==32
summarize Leftist if gnumber_new==32
summarize Reactionary if gnumber_new==32
 
 
*Revolutionary Cells*
summarize Warning if gnumber_new==127
tab target_state if gnumber_new==127
summarize Polity2 if gnumber_new==127
summarize PTS if gnumber_new==127
summarize Territory if gnumber_new==127
summarize State_Sponsored if gnumber_new==127
summarize Resources if gnumber_new==127
summarize Separatist if gnumber_new==127
summarize Suicide if gnumber_new==127
summarize Religious if gnumber_new==127
summarize Ethnic if gnumber_new==127
summarize Leftist if gnumber_new==127
summarize Reactionary if gnumber_new==127


*Revolutionary Organization of People in Arms (ORPA)*
summarize Warning if gnumber_new==128
tab target_state if gnumber_new==128
summarize Polity2 if gnumber_new==128
summarize PTS if gnumber_new==128
summarize Territory if gnumber_new==128
summarize State_Sponsored if gnumber_new==128
summarize Resources if gnumber_new==128
summarize Separatist if gnumber_new==128
summarize Suicide if gnumber_new==128
summarize Religious if gnumber_new==128
summarize Ethnic if gnumber_new==128
summarize Leftist if gnumber_new==128
summarize Reactionary if gnumber_new==128
 
 
*Revolutionary People’s Army (ERP) (Argentina)*
summarize Warning if gnumber_new==94
tab target_state if gnumber_new==94
summarize Polity2 if gnumber_new==94
summarize PTS if gnumber_new==94
summarize Territory if gnumber_new==94
summarize State_Sponsored if gnumber_new==94
summarize Resources if gnumber_new==94
summarize Separatist if gnumber_new==94
summarize Suicide if gnumber_new==94
summarize Religious if gnumber_new==94
summarize Ethnic if gnumber_new==94
summarize Leftist if gnumber_new==94
summarize Reactionary if gnumber_new==94


*Revolutionary People’s Struggle (ELA)*
summarize Warning if gnumber_new==73
tab target_state if gnumber_new==73
summarize Polity2 if gnumber_new==73
summarize PTS if gnumber_new==73
summarize Territory if gnumber_new==73
summarize State_Sponsored if gnumber_new==73
summarize Resources if gnumber_new==73
summarize Separatist if gnumber_new==73
summarize Suicide if gnumber_new==73
summarize Religious if gnumber_new==73
summarize Ethnic if gnumber_new==73
summarize Leftist if gnumber_new==73
summarize Reactionary if gnumber_new==73


*Runda Kumpulan Kecil (RKK)*
summarize Warning if gnumber_new==45
tab target_state if gnumber_new==45
summarize Polity2 if gnumber_new==45
summarize PTS if gnumber_new==45
summarize Territory if gnumber_new==45
summarize State_Sponsored if gnumber_new==45
summarize Resources if gnumber_new==45
summarize Separatist if gnumber_new==45
summarize Suicide if gnumber_new==45
summarize Religious if gnumber_new==45
summarize Ethnic if gnumber_new==45
summarize Leftist if gnumber_new==45
summarize Reactionary if gnumber_new==45
 
 
*Salafist Group for Preaching and Fighting (GSPC)*
summarize Warning if gnumber_new==129
tab target_state if gnumber_new==129
summarize Polity2 if gnumber_new==129
summarize PTS if gnumber_new==129
summarize Territory if gnumber_new==129
summarize State_Sponsored if gnumber_new==129
summarize Resources if gnumber_new==129
summarize Separatist if gnumber_new==129
summarize Suicide if gnumber_new==129
summarize Religious if gnumber_new==129
summarize Ethnic if gnumber_new==129
summarize Leftist if gnumber_new==129
summarize Reactionary if gnumber_new==129
 
 
*Sanaa Province of the Islamic State*
summarize Warning if gnumber_new==130
tab target_state if gnumber_new==130
summarize Polity2 if gnumber_new==130
summarize PTS if gnumber_new==130
summarize Territory if gnumber_new==130
summarize State_Sponsored if gnumber_new==130
summarize Resources if gnumber_new==130
summarize Separatist if gnumber_new==130
summarize Suicide if gnumber_new==130
summarize Religious if gnumber_new==130
summarize Ethnic if gnumber_new==130
summarize Leftist if gnumber_new==130
summarize Reactionary if gnumber_new==130
 
 
*Sandinista National Liberation Front (FSLN)*
summarize Warning if gnumber_new==131
tab target_state if gnumber_new==131
summarize Polity2 if gnumber_new==131
summarize PTS if gnumber_new==131
summarize Territory if gnumber_new==131
summarize State_Sponsored if gnumber_new==131
summarize Resources if gnumber_new==131
summarize Separatist if gnumber_new==131
summarize Suicide if gnumber_new==131
summarize Religious if gnumber_new==131
summarize Ethnic if gnumber_new==131
summarize Leftist if gnumber_new==131
summarize Reactionary if gnumber_new==131
 
 
*Shining Path (SL)*
summarize Warning if gnumber_new==33
tab target_state if gnumber_new==33
summarize Polity2 if gnumber_new==33
summarize PTS if gnumber_new==33
summarize Territory if gnumber_new==33
summarize State_Sponsored if gnumber_new==33
summarize Resources if gnumber_new==33
summarize Separatist if gnumber_new==33
summarize Suicide if gnumber_new==33
summarize Religious if gnumber_new==33
summarize Ethnic if gnumber_new==33
summarize Leftist if gnumber_new==33
summarize Reactionary if gnumber_new==33


*Simon Bolivar Guerrilla Coordinating Board (CGSB)*
summarize Warning if gnumber_new==74
tab target_state if gnumber_new==74
summarize Polity2 if gnumber_new==74
summarize PTS if gnumber_new==74
summarize Territory if gnumber_new==74
summarize State_Sponsored if gnumber_new==74
summarize Resources if gnumber_new==74
summarize Separatist if gnumber_new==74
summarize Suicide if gnumber_new==74
summarize Religious if gnumber_new==74
summarize Ethnic if gnumber_new==74
summarize Leftist if gnumber_new==74
summarize Reactionary if gnumber_new==74
 
 
*Sinai Province of the Islamic State*
summarize Warning if gnumber_new==46
tab target_state if gnumber_new==46
summarize Polity2 if gnumber_new==46
summarize PTS if gnumber_new==46
summarize Territory if gnumber_new==46
summarize State_Sponsored if gnumber_new==46
summarize Resources if gnumber_new==46
summarize Separatist if gnumber_new==46
summarize Suicide if gnumber_new==46
summarize Religious if gnumber_new==46
summarize Ethnic if gnumber_new==46
summarize Leftist if gnumber_new==46
summarize Reactionary if gnumber_new==46
 
 
*Sindhu Desh Liberation Army (SDLA)*
summarize Warning if gnumber_new==75
tab target_state if gnumber_new==75
summarize Polity2 if gnumber_new==75
summarize PTS if gnumber_new==75
summarize Territory if gnumber_new==75
summarize State_Sponsored if gnumber_new==75
summarize Resources if gnumber_new==75
summarize Separatist if gnumber_new==75
summarize Suicide if gnumber_new==75
summarize Religious if gnumber_new==75
summarize Ethnic if gnumber_new==75
summarize Leftist if gnumber_new==75
summarize Reactionary if gnumber_new==75


*South-West Africa People's Organization (SWAPO)*
summarize Warning if gnumber_new==132
tab target_state if gnumber_new==132
summarize Polity2 if gnumber_new==132
summarize PTS if gnumber_new==132
summarize Territory if gnumber_new==132
summarize State_Sponsored if gnumber_new==132
summarize Resources if gnumber_new==132
summarize Separatist if gnumber_new==132
summarize Suicide if gnumber_new==132
summarize Religious if gnumber_new==132
summarize Ethnic if gnumber_new==132
summarize Leftist if gnumber_new==132
summarize Reactionary if gnumber_new==132


*Sudan People's Liberation Movement - North*
summarize Warning if gnumber_new==133
tab target_state if gnumber_new==133
summarize Polity2 if gnumber_new==133
summarize PTS if gnumber_new==133
summarize Territory if gnumber_new==133
summarize State_Sponsored if gnumber_new==133
summarize Resources if gnumber_new==133
summarize Separatist if gnumber_new==133
summarize Suicide if gnumber_new==133
summarize Religious if gnumber_new==133
summarize Ethnic if gnumber_new==133
summarize Leftist if gnumber_new==133
summarize Reactionary if gnumber_new==133


*Taliban*
summarize Warning if gnumber_new==34
tab target_state if gnumber_new==34
summarize Polity2 if gnumber_new==34
summarize PTS if gnumber_new==34
summarize Territory if gnumber_new==34
summarize State_Sponsored if gnumber_new==34
summarize Resources if gnumber_new==34
summarize Separatist if gnumber_new==34
summarize Suicide if gnumber_new==34
summarize Religious if gnumber_new==34
summarize Ethnic if gnumber_new==34
summarize Leftist if gnumber_new==34
summarize Reactionary if gnumber_new==34


*Tawhid and Jihad*
summarize Warning if gnumber_new==134
tab target_state if gnumber_new==134
summarize Polity2 if gnumber_new==134
summarize PTS if gnumber_new==134
summarize Territory if gnumber_new==134
summarize State_Sponsored if gnumber_new==134
summarize Resources if gnumber_new==134
summarize Separatist if gnumber_new==134
summarize Suicide if gnumber_new==134
summarize Religious if gnumber_new==134
summarize Ethnic if gnumber_new==134
summarize Leftist if gnumber_new==134
summarize Reactionary if gnumber_new==134


*Tehrik-i-Taliban Pakistan (TTP)*
summarize Warning if gnumber_new==35
tab target_state if gnumber_new==35
summarize Polity2 if gnumber_new==35
summarize PTS if gnumber_new==35
summarize Territory if gnumber_new==35
summarize State_Sponsored if gnumber_new==35
summarize Resources if gnumber_new==35
summarize Separatist if gnumber_new==35
summarize Suicide if gnumber_new==35
summarize Religious if gnumber_new==35
summarize Ethnic if gnumber_new==35
summarize Leftist if gnumber_new==35
summarize Reactionary if gnumber_new==35


*Terra Lliure*
summarize Warning if gnumber_new==76
tab target_state if gnumber_new==76
summarize Polity2 if gnumber_new==76
summarize PTS if gnumber_new==76
summarize Territory if gnumber_new==76
summarize State_Sponsored if gnumber_new==76
summarize Resources if gnumber_new==76
summarize Separatist if gnumber_new==76
summarize Suicide if gnumber_new==76
summarize Religious if gnumber_new==76
summarize Ethnic if gnumber_new==76
summarize Leftist if gnumber_new==76
summarize Reactionary if gnumber_new==76


*Tripoli Province of the Islamic State*
summarize Warning if gnumber_new==47
tab target_state if gnumber_new==47
summarize Polity2 if gnumber_new==47
summarize PTS if gnumber_new==47
summarize Territory if gnumber_new==47
summarize State_Sponsored if gnumber_new==47
summarize Resources if gnumber_new==47
summarize Separatist if gnumber_new==47
summarize Suicide if gnumber_new==47
summarize Religious if gnumber_new==47
summarize Ethnic if gnumber_new==47
summarize Leftist if gnumber_new==47
summarize Reactionary if gnumber_new==47


*Tupac Amaru Revolutionary Movement (MRTA)*
summarize Warning if gnumber_new==36
tab target_state if gnumber_new==36
summarize Polity2 if gnumber_new==36
summarize PTS if gnumber_new==36
summarize Territory if gnumber_new==36
summarize State_Sponsored if gnumber_new==36
summarize Resources if gnumber_new==36
summarize Separatist if gnumber_new==36
summarize Suicide if gnumber_new==36
summarize Religious if gnumber_new==36
summarize Ethnic if gnumber_new==36
summarize Leftist if gnumber_new==36
summarize Reactionary if gnumber_new==36


*Ulster Freedom Fighters (UFF)*
summarize Warning if gnumber_new==135
tab target_state if gnumber_new==135
summarize Polity2 if gnumber_new==135
summarize PTS if gnumber_new==135
summarize Territory if gnumber_new==135
summarize State_Sponsored if gnumber_new==135
summarize Resources if gnumber_new==135
summarize Separatist if gnumber_new==135
summarize Suicide if gnumber_new==135
summarize Religious if gnumber_new==135
summarize Ethnic if gnumber_new==135
summarize Leftist if gnumber_new==135
summarize Reactionary if gnumber_new==135


*Ulster Volunteer Force (UVF)*
summarize Warning if gnumber_new==77
tab target_state if gnumber_new==77
summarize Polity2 if gnumber_new==77
summarize PTS if gnumber_new==77
summarize Territory if gnumber_new==77
summarize State_Sponsored if gnumber_new==77
summarize Resources if gnumber_new==77
summarize Separatist if gnumber_new==77
summarize Suicide if gnumber_new==77
summarize Religious if gnumber_new==77
summarize Ethnic if gnumber_new==77
summarize Leftist if gnumber_new==77
summarize Reactionary if gnumber_new==77


*United Baloch Army (UBA)*
summarize Warning if gnumber_new==78
tab target_state if gnumber_new==78
summarize Polity2 if gnumber_new==78
summarize PTS if gnumber_new==78
summarize Territory if gnumber_new==78
summarize State_Sponsored if gnumber_new==78
summarize Resources if gnumber_new==78
summarize Separatist if gnumber_new==78
summarize Suicide if gnumber_new==78
summarize Religious if gnumber_new==78
summarize Ethnic if gnumber_new==78
summarize Leftist if gnumber_new==78
summarize Reactionary if gnumber_new==78


*United Liberation Front of Assam (ULFA)*
summarize Warning if gnumber_new==37
tab target_state if gnumber_new==37
summarize Polity2 if gnumber_new==37
summarize PTS if gnumber_new==37
summarize Territory if gnumber_new==37
summarize State_Sponsored if gnumber_new==37
summarize Resources if gnumber_new==37
summarize Separatist if gnumber_new==37
summarize Suicide if gnumber_new==37
summarize Religious if gnumber_new==37
summarize Ethnic if gnumber_new==37
summarize Leftist if gnumber_new==37
summarize Reactionary if gnumber_new==37


*United Popular Action Movement*
summarize Warning if gnumber_new==79
tab target_state if gnumber_new==79
summarize Polity2 if gnumber_new==79
summarize PTS if gnumber_new==79
summarize Territory if gnumber_new==79
summarize State_Sponsored if gnumber_new==79
summarize Resources if gnumber_new==79
summarize Separatist if gnumber_new==79
summarize Suicide if gnumber_new==79
summarize Religious if gnumber_new==79
summarize Ethnic if gnumber_new==79
summarize Leftist if gnumber_new==79
summarize Reactionary if gnumber_new==79


*Weather Underground/Weathermen*
summarize Warning if gnumber_new==136
tab target_state if gnumber_new==136
summarize Polity2 if gnumber_new==136
summarize PTS if gnumber_new==136
summarize Territory if gnumber_new==136
summarize State_Sponsored if gnumber_new==136
summarize Resources if gnumber_new==136
summarize Separatist if gnumber_new==136
summarize Suicide if gnumber_new==136
summarize Religious if gnumber_new==136
summarize Ethnic if gnumber_new==136
summarize Leftist if gnumber_new==136
summarize Reactionary if gnumber_new==136
